pub struct ExactUpload<'source> { /* private fields */ }Expand description
One immutable exact object together with a replayable source for its final stored bytes. Provider adapters derive their own native checksums from this source and can reopen it after an ambiguous create response.
Implementations
Sourceimpl<'source> ExactUpload<'source>
impl<'source> ExactUpload<'source>
pub fn from_bytes( object: &'source ExactObjectRef, bytes: &'source [u8], ) -> Result<Self, StorageError>
pub async fn from_file( object: &'source ExactObjectRef, path: &'source Path, ) -> Result<Self, StorageError>
pub fn object(&self) -> &ExactObjectRef
pub fn source(&self) -> ExactUploadSource<'source>
pub fn verify_stored_bytes(&self, bytes: &[u8]) -> Result<(), CloudHomeError>
pub async fn body(&self) -> Result<BlobBody, CloudHomeError>